# PyUpdater Azure Blob Storage plugin

**Probs not ready to use yet! 🙃**

[PyUpdater](https://github.com/Digital-Sapphire/PyUpdater) upload plugin for Azure Blob Storage

Run `pyupdater settings --plugin azure-blobs` to set up. Get the configuration string from your access keys in Azure and the name of the container you wish to upload your update files to.

(Feel free to contribute)
